@@ -23,18 +23,21 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $Id: emboss.c,v 1.22 2000/08/22 01:26:54 neo Exp $
+ * $Id: emboss.c,v 1.42 2004/01/20 17:07:35 mitch Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
 #include <sys/types.h>
 
+#ifdef __GNUC__
+#warning GTK_DISABLE_DEPRECATED
+#endif
+#undef GTK_DISABLE_DEPRECATED
+
 #include <gtk/gtk.h>
 
 #include <libgimp/gimp.h>
@@ -49,22 +52,7 @@ enum
   FUNCTION_EMBOSS  = 1
 };
 
-struct Grgb
-{
-  guint8 red;
-  guint8 green;
-  guint8 blue;
-};
-
-struct GRegion
-{
-  gint32 x;
-  gint32 y;
-  gint32 width;
-  gint32 height;
-};
-
-struct piArgs
+typedef struct
 {
   gint32 img;
   gint32 drw;
@@ -72,7 +60,7 @@ struct piArgs
   gdouble elevation;
   gint32 depth;
   gint32 embossp;
-};
+} piArgs;
 
 struct embossFilter
 {
@@ -87,34 +75,34 @@ struct embossFilter
 
 /*  preview stuff -- to be removed as soon as we have a real libgimp preview  */
 
-struct mwPreview
+typedef struct
 {
   gint     width;
   gint     height;
   gint     bpp;
   gdouble  scale;
   guchar  *bits;
-};
+} mwPreview;
 
 #define PREVIEW_SIZE 100
 
 static gint do_preview = TRUE;
 
-static GtkWidget        * mw_preview_new   (GtkWidget        *parent,
-					    struct mwPreview *mwp);
-static struct mwPreview * mw_preview_build (GimpDrawable        *drw);
+static GtkWidget *mw_preview_new   (GtkWidget        *parent,
+				    mwPreview *mwp);
+static mwPreview *mw_preview_build (GimpDrawable        *drw);
 
 
 
 static void query (void);
-static void run   (gchar   *name,
-		   gint     nparam,
-		   GimpParam  *param,
-		   gint    *nretvals,
-		   GimpParam **retvals);
+static void run   (const gchar      *name,
+		   gint              nparam,
+		   const GimpParam  *param,
+		   gint             *nretvals,
+		   GimpParam       **retvals);
 
-static gint pluginCore        (struct piArgs *argp);
-static gint pluginCoreIA      (struct piArgs *argp);
+static gint pluginCore        (piArgs *argp);
+static gint pluginCoreIA      (piArgs *argp);
 
 static void emboss_do_preview (GtkWidget     *preview);
 
@@ -138,7 +126,7 @@ GimpPlugInInfo PLUG_IN_INFO =
   run,   /* run   */
 };
 
-static struct mwPreview *thePreview;
+static mwPreview *thePreview;
 
 MAIN ()
 
@@ -155,7 +143,6 @@ query (void)
     { GIMP_PDB_INT32, "depth", "The Filter Width" },
     { GIMP_PDB_INT32, "embossp", "Emboss or Bumpmap" }
   };
-  static gint nargs = sizeof (args) / sizeof (args[0]);
 
   gimp_install_procedure ("plug_in_emboss",
 			  "Emboss filter",
@@ -164,28 +151,30 @@ query (void)
 			  "Eric L. Hernes, John Schlag",
 			  "Eric L. Hernes",
 			  "1997",
-			  N_("<Image>/Filters/Distorts/Emboss..."),
+			  N_("<Image>/Filters/Distorts/_Emboss..."),
 			  "RGB*",
 			  GIMP_PLUGIN,
-			  nargs, 0,
+			  G_N_ELEMENTS (args), 0,
 			  args, NULL);
 }
 
 static void
-run (gchar   *name,
-     gint     nparam,
-     GimpParam  *param,
-     gint    *nretvals,
-     GimpParam **retvals)
+run (const gchar      *name,
+     gint              nparam,
+     const GimpParam  *param,
+     gint             *nretvals,
+     GimpParam       **retvals)
 {
-  static GimpParam rvals[1];
-  struct piArgs args;
-  GimpDrawable *drw;
+  static GimpParam  rvals[1];
+  piArgs            args;
+  GimpDrawable     *drw;
 
   *nretvals = 1;
   *retvals = rvals;
 
-  memset(&args, (int) 0, sizeof (struct piArgs));
+  INIT_I18N ();
+
+  memset(&args, (int) 0, sizeof (piArgs));
 
   rvals[0].type = GIMP_PDB_STATUS;
   rvals[0].data.d_status = GIMP_PDB_SUCCESS;
@@ -193,7 +182,6 @@ run (gchar   *name,
   switch (param[0].data.d_int32)
     {
     case GIMP_RUN_INTERACTIVE:
-      INIT_I18N_UI();
       args.img = args.drw = 0;
       gimp_get_data ("plug_in_emboss", &args);
       if (args.img == 0 && args.drw == 0)
@@ -215,7 +203,7 @@ run (gchar   *name,
 	}
       else
 	{
-	  gimp_set_data ("plug_in_emboss", &args, sizeof (struct piArgs));
+	  gimp_set_data ("plug_in_emboss", &args, sizeof (piArgs));
 	}
 
       break;
@@ -227,7 +215,6 @@ run (gchar   *name,
 	  break;
 	}
 
-      INIT_I18N();
       args.img = param[1].data.d_image;
       args.drw = param[2].data.d_drawable;
       args.azimuth = param[3].data.d_float;
@@ -243,7 +230,6 @@ run (gchar   *name,
       break;
 
     case GIMP_RUN_WITH_LAST_VALS:
-      INIT_I18N();
       gimp_get_data("plug_in_emboss", &args);
       /* use this image and drawable, even with last args */
       args.img = param[1].data.d_image;
@@ -373,7 +359,7 @@ EmbossRow (guchar *src,
 }
 
 static gint
-pluginCore (struct piArgs *argp)
+pluginCore (piArgs *argp)
 {
   GimpDrawable *drw;
   GimpPixelRgn src, dst;
@@ -404,11 +390,8 @@ pluginCore (struct piArgs *argp)
   gimp_pixel_rgn_init (&src, drw, x1, y1, width, height, FALSE, FALSE);
   gimp_pixel_rgn_init (&dst, drw, x1, y1, width, height, TRUE, TRUE);
 
-  srcbuf = g_new (guchar, rowsize * 3);
-  dstbuf = g_new (guchar, rowsize);
-
-  memset (srcbuf, 0, (size_t) rowsize * 3);
-  memset (dstbuf, 0, (size_t) rowsize);
+  srcbuf = g_new0 (guchar, rowsize * 3);
+  dstbuf = g_new0 (guchar, rowsize);
 
   EmbossInit (DtoR(argp->azimuth), DtoR(argp->elevation), argp->depth);
   gimp_progress_init (_("Emboss"));
@@ -445,24 +428,13 @@ pluginCore (struct piArgs *argp)
   g_free (dstbuf);
 
   gimp_drawable_flush (drw);
-  gimp_drawable_merge_shadow (drw->id, TRUE);
-  gimp_drawable_update (drw->id, x1, y1, width, height);
+  gimp_drawable_merge_shadow (drw->drawable_id, TRUE);
+  gimp_drawable_update (drw->drawable_id, x1, y1, width, height);
   gimp_displays_flush ();
 
   return 0;
 }
 
-gboolean run_flag = FALSE;
-
-static void
-emboss_ok_callback (GtkWidget *widget,
-		    gpointer   data)
-{
-  run_flag = TRUE;
-
-  gtk_widget_destroy (GTK_WIDGET (data));
-}
-
 static void
 emboss_radio_button_callback (GtkWidget *widget,
 			      gpointer   data)
@@ -502,7 +474,7 @@ emboss_int_adjustment_callback (GtkAdjustment *adj,
 }
 
 static gint
-pluginCoreIA (struct piArgs *argp)
+pluginCoreIA (piArgs *argp)
 {
   GtkWidget *dlg;
   GtkWidget *main_vbox;
@@ -511,25 +483,19 @@ pluginCoreIA (struct piArgs *argp)
   GtkWidget *preview;
   GtkWidget *frame;
   GtkObject *adj;
+  gboolean   run;
 
   gimp_ui_init ("emboss", TRUE);
 
   dlg = gimp_dialog_new (_("Emboss"), "emboss",
-			 gimp_standard_help_func, "filters/emboss.html",
-			 GTK_WIN_POS_MOUSE,
-			 FALSE, TRUE, FALSE,
+                         NULL, 0,
+			 gimp_standard_help_func, "plug-in-emboss",
 
-			 _("OK"), emboss_ok_callback,
-			 NULL, NULL, NULL, TRUE, FALSE,
-			 _("Cancel"), gtk_widget_destroy,
-			 NULL, 1, NULL, FALSE, TRUE,
+			 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+			 GTK_STOCK_OK,     GTK_RESPONSE_OK,
 
 			 NULL);
 
-  gtk_signal_connect (GTK_OBJECT (dlg), "destroy",
-		      GTK_SIGNAL_FUNC (gtk_main_quit),
-		      NULL);
-
   main_vbox = gtk_vbox_new (FALSE, 4);
   gtk_container_set_border_width (GTK_CONTAINER (main_vbox), 6);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), main_vbox,
@@ -541,23 +507,22 @@ pluginCoreIA (struct piArgs *argp)
   gtk_widget_show (hbox);
 
   preview = mw_preview_new (hbox, thePreview);
-  gtk_object_set_data (GTK_OBJECT (preview), "piArgs", argp);
+  g_object_set_data (G_OBJECT (preview), "piArgs", argp);
   emboss_do_preview (preview);
 
-  frame = gimp_radio_group_new2 (TRUE, _("Function"),
-				 emboss_radio_button_callback,
-				 &argp->embossp, (gpointer) argp->embossp,
+  frame = gimp_int_radio_group_new (TRUE, _("Function"),
+				    G_CALLBACK (emboss_radio_button_callback),
+				    &argp->embossp, argp->embossp,
 
-				 _("Bumpmap"), (gpointer) FUNCTION_BUMPMAP, NULL,
-				 _("Emboss"), (gpointer) FUNCTION_EMBOSS, NULL,
+				    _("_Bumpmap"), FUNCTION_BUMPMAP, NULL,
+				    _("_Emboss"),  FUNCTION_EMBOSS,  NULL,
 
-				 NULL);
+				    NULL);
 
   gtk_box_pack_start (GTK_BOX (hbox), frame, TRUE, TRUE, 0);
   gtk_widget_show (frame);
 
   frame = gtk_frame_new (_("Parameter Settings"));
-  gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
   gtk_box_pack_start (GTK_BOX (main_vbox), frame, FALSE, FALSE, 0);
   gtk_widget_show (frame);
 
@@ -568,40 +533,41 @@ pluginCoreIA (struct piArgs *argp)
   gtk_container_add (GTK_CONTAINER (frame), table);
 
   adj = gimp_scale_entry_new (GTK_TABLE (table), 0, 0,
-			      _("Azimuth:"), 100, 0,
+			      _("_Azimuth:"), 100, 6,
 			      argp->azimuth, 0.0, 360.0, 1.0, 10.0, 2,
 			      TRUE, 0, 0,
 			      NULL, NULL);
-  gtk_signal_connect (GTK_OBJECT (adj), "value_changed",
-		      GTK_SIGNAL_FUNC (emboss_float_adjustment_callback),
-		      &argp->azimuth);
+  g_signal_connect (adj, "value_changed",
+                    G_CALLBACK (emboss_float_adjustment_callback),
+                    &argp->azimuth);
 
   adj = gimp_scale_entry_new (GTK_TABLE (table), 0, 1,
-			      _("Elevation:"), 100, 0,
+			      _("E_levation:"), 100, 6,
 			      argp->elevation, 0.0, 180.0, 1.0, 10.0, 2,
 			      TRUE, 0, 0,
 			      NULL, NULL);
-  gtk_signal_connect (GTK_OBJECT (adj), "value_changed",
-		      GTK_SIGNAL_FUNC (emboss_float_adjustment_callback),
-		      &argp->elevation);
+  g_signal_connect (adj, "value_changed",
+                    G_CALLBACK (emboss_float_adjustment_callback),
+                    &argp->elevation);
 
   adj = gimp_scale_entry_new (GTK_TABLE (table), 0, 2,
-			      _("Depth:"), 100, 0,
+			      _("_Depth:"), 100, 6,
 			      argp->depth, 1.0, 100.0, 1.0, 5.0, 0,
 			      TRUE, 0, 0,
 			      NULL, NULL);
-  gtk_signal_connect (GTK_OBJECT (adj), "value_changed",
-		      GTK_SIGNAL_FUNC (emboss_int_adjustment_callback),
-		      &argp->depth);
+  g_signal_connect (adj, "value_changed",
+                    G_CALLBACK (emboss_int_adjustment_callback),
+                    &argp->depth);
 
   gtk_widget_show (table);
 
   gtk_widget_show (dlg);
 
-  gtk_main ();
-  gdk_flush ();
+  run = (gimp_dialog_run (GIMP_DIALOG (dlg)) == GTK_RESPONSE_OK);
 
-  if (run_flag)
+  gtk_widget_destroy (dlg);
+
+  if (run)
     return pluginCore (argp);
   else
     return -1;
@@ -611,7 +577,7 @@ static void
 emboss_do_preview (GtkWidget *w)
 {
   static GtkWidget *theWidget = NULL;
-  struct piArgs *ap;
+  piArgs *ap;
   guchar *dst, *c;
   gint y, rowsize;
 
@@ -620,7 +586,7 @@ emboss_do_preview (GtkWidget *w)
       theWidget = w;
     }
 
-  ap = gtk_object_get_data (GTK_OBJECT (theWidget), "piArgs");
+  ap = g_object_get_data (G_OBJECT (theWidget), "piArgs");
   rowsize = thePreview->width * thePreview->bpp;
 
   dst = g_malloc (rowsize);
@@ -654,8 +620,8 @@ emboss_do_preview (GtkWidget *w)
 			    dst, 0, y, thePreview->width);
     }
 
-  gtk_widget_draw (theWidget, NULL);
-  gdk_flush ();
+  gtk_widget_queue_draw (theWidget);
+
   g_free (dst);
 }
 
@@ -669,12 +635,12 @@ mw_preview_toggle_callback (GtkWidget *widget,
     emboss_do_preview (NULL);
 }
 
-static struct mwPreview *
+static mwPreview *
 mw_preview_build_virgin (GimpDrawable *drw)
 {
-  struct mwPreview *mwp;
+  mwPreview *mwp;
 
-  mwp = g_new (struct mwPreview, 1);
+  mwp = g_new (mwPreview, 1);
 
   if (drw->width > drw->height)
     {
@@ -695,10 +661,10 @@ mw_preview_build_virgin (GimpDrawable *drw)
   return mwp;
 }
 
-static struct mwPreview *
+static mwPreview *
 mw_preview_build (GimpDrawable *drw)
 {
-  struct mwPreview *mwp;
+  mwPreview *mwp;
   gint x, y, b;
   guchar *bc;
   guchar *drwBits;
@@ -728,16 +694,15 @@ mw_preview_build (GimpDrawable *drw)
 
 static GtkWidget *
 mw_preview_new (GtkWidget        *parent,
-                struct mwPreview *mwp)
+                mwPreview *mwp)
 {
   GtkWidget *preview;
   GtkWidget *frame;
   GtkWidget *pframe;
   GtkWidget *vbox;
   GtkWidget *button;
-   
+
   frame = gtk_frame_new (_("Preview"));
-  gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
   gtk_box_pack_start (GTK_BOX (parent), frame, FALSE, FALSE, 0);
   gtk_widget_show (frame);
 
@@ -756,13 +721,14 @@ mw_preview_new (GtkWidget        *parent,
   gtk_container_add (GTK_CONTAINER (pframe), preview);
   gtk_widget_show (preview);
 
-  button = gtk_check_button_new_with_label (_("Do Preview"));
+  button = gtk_check_button_new_with_mnemonic (_("Do _Preview"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), do_preview);
-  gtk_signal_connect (GTK_OBJECT (button), "toggled",
-                      GTK_SIGNAL_FUNC (mw_preview_toggle_callback),
-                      &do_preview);
   gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
   gtk_widget_show (button);
 
+  g_signal_connect (button, "toggled",
+                    G_CALLBACK (mw_preview_toggle_callback),
+                    &do_preview);
+
   return preview;
 }
