@@ -30,13 +30,13 @@
 			    pixelize
 			    pixel-size
 			    keep-selection
-			    seperate-layer)
+			    separate-layer)
   (let* (
 	 (type (car (gimp-drawable-type-with-alpha drawable)))
 	 (image-width (car (gimp-image-width image)))
 	 (image-height (car (gimp-image-height image))))
     
-    (gimp-image-undo-disable image)
+    (gimp-image-undo-group-start image)
     (gimp-layer-add-alpha drawable)
     
     (if (= (car (gimp-selection-is-empty image)) TRUE)
@@ -55,7 +55,7 @@
     (set! select-width (- (cadr (cddr selection-bounds)) select-offset-x))
     (set! select-height (- (caddr (cddr selection-bounds)) select-offset-y))
     
-    (if (= seperate-layer TRUE)
+    (if (= separate-layer TRUE)
 	(begin
 	  (set! effect-layer (car (gimp-layer-new image
 						select-width
@@ -63,7 +63,7 @@
 						type
 						"glow layer"
 						100
-						NORMAL)))
+						NORMAL-MODE)))
     
 	  (gimp-layer-set-offsets effect-layer select-offset-x select-offset-y)
 	  (gimp-image-add-layer image effect-layer -1)
@@ -82,7 +82,7 @@
     (if (= pixelize TRUE)
 	(plug-in-pixelize 1 image active-layer pixel-size))
     (plug-in-max-rgb 1 image active-layer 0)
-    (plug-in-edge 1 image active-layer edge-amount 1)
+    (plug-in-edge 1 image active-layer edge-amount 1 0)
     
     ; clean up the selection copy
     (gimp-selection-load active-selection)
@@ -90,28 +90,22 @@
     (if (= keep-selection FALSE)
 	(gimp-selection-none image))
     
-    (gimp-image-undo-enable image)
     (gimp-image-set-active-layer image drawable)
     (gimp-image-remove-channel image active-selection)
+    (gimp-image-undo-group-end image)
     (gimp-displays-flush)))
 
 (script-fu-register "script-fu-predator"
-		    "<Image>/Script-Fu/Alchemy/Predator..."
-		    "Fills the current selection with test"
+		    _"<Image>/Script-Fu/Alchemy/_Predator..."
+		    "Looks like images from the movie Predator"
 		    "Adrian Likins <adrian@gimp.org>"
 		    "Adrian Likins"
 		    "10/12/97"
-		    "RGB RGBA"
-		    SF-IMAGE "Image" 0
-		    SF-DRAWABLE "Drawable" 0
-		    SF-ADJUSTMENT "edge-amount" '(2 0 24 1 1 0 0)
-		    SF-TOGGLE "pixelize?" TRUE
-		    SF-ADJUSTMENT "Pixel Amount" '(3 1 16 1 1 0 0)
-		    SF-TOGGLE "Keep Selection?" TRUE
-		    SF-TOGGLE "Seperate Layer?" TRUE)
-
-
-
-
-
-
+		    "RGB*"
+		    SF-IMAGE       "Image"          0
+		    SF-DRAWABLE    "Drawable"       0
+		    SF-ADJUSTMENT _"Edge Amount"    '(2 0 24 1 1 0 0)
+		    SF-TOGGLE     _"Pixelize"       TRUE
+		    SF-ADJUSTMENT _"Pixel Amount"   '(3 1 16 1 1 0 0)
+		    SF-TOGGLE     _"Keep Selection" TRUE
+		    SF-TOGGLE     _"Separate Layer" TRUE)
